searchData={"items":[{"type":"module","title":"ExQPDF","doc":"An Elixir wrapper for the QPDF library.\n\nQPDF is a command-line program and C++ library for structural, content-preserving\ntransformations on PDF files. ExQPDF provides a simple interface to some of its\nfunctionality, focusing on retrieving PDF information and handling password-protected files.","ref":"ExQPDF.html"},{"type":"module","title":"Features - ExQPDF","doc":"* Check if a PDF requires a password to open\n* Get information about PDF files (page count, etc.)\n* Open PDFs with or without passwords for future operations","ref":"ExQPDF.html#module-features"},{"type":"module","title":"Requirements - ExQPDF","doc":"This library requires the QPDF command-line tool to be installed on your system.\nSee the README for installation instructions for various platforms.","ref":"ExQPDF.html#module-requirements"},{"type":"module","title":"Examples - ExQPDF","doc":"Check if a PDF requires a password:\n\n    path = \"/path/to/document.pdf\"\n    case ExQPDF.password_required?(path) do\n      {:ok, true} -> \"Password required\"\n      {:ok, false} -> \"No password required\"\n      {:error, reason} -> \"Error: #{reason}\"\n    end\n\nGet information about a PDF:\n\n    # For a PDF without password protection\n    {:ok, info} = ExQPDF.info(\"/path/to/document.pdf\")\n    \"Page count: #{info.page_count}\"\n\n    # For a password-protected PDF\n    {:ok, info} = ExQPDF.info(\"/path/to/protected.pdf\", password: \"secret\")\n    \"Page count: #{info.page_count}\"","ref":"ExQPDF.html#module-examples"},{"type":"function","title":"ExQPDF.info/2","doc":"Gets general information about a PDF file.","ref":"ExQPDF.html#info/2"},{"type":"function","title":"Parameters - ExQPDF.info/2","doc":"- `path` - Path to the PDF file\n  - `opts` - Options including:\n    - `:password` - Password for protected PDFs","ref":"ExQPDF.html#info/2-parameters"},{"type":"function","title":"Returns - ExQPDF.info/2","doc":"- `{:ok, info}` - A map containing file information\n  - `{:error, reason}` - An error occurred","ref":"ExQPDF.html#info/2-returns"},{"type":"function","title":"Examples - ExQPDF.info/2","doc":"# If the file doesn't exist, an error is returned\n    iex> ExQPDF.info(\"non_existent_file.pdf\")\n    {:error, \"File not found: non_existent_file.pdf\"}\n\n    # With optional password parameter\n    iex> ExQPDF.info(\"non_existent_file.pdf\", password: \"secret\")\n    {:error, \"File not found: non_existent_file.pdf\"}","ref":"ExQPDF.html#info/2-examples"},{"type":"function","title":"ExQPDF.metadata/2","doc":"Extracts metadata from a PDF file.\n\nThis function extracts metadata such as title, author, creation date, and more from a PDF file.\nFor password-protected PDFs, a password can be provided.","ref":"ExQPDF.html#metadata/2"},{"type":"function","title":"Parameters - ExQPDF.metadata/2","doc":"- `path` - Path to the PDF file\n  - `opts` - Options including:\n    - `:password` - Password for protected PDFs","ref":"ExQPDF.html#metadata/2-parameters"},{"type":"function","title":"Returns - ExQPDF.metadata/2","doc":"- `{:ok, metadata}` - A map containing metadata information\n  - `{:error, reason}` - An error occurred","ref":"ExQPDF.html#metadata/2-returns"},{"type":"function","title":"Examples - ExQPDF.metadata/2","doc":"# If the file doesn't exist, an error is returned\n    iex> ExQPDF.metadata(\"non_existent_file.pdf\")\n    {:error, \"File not found: non_existent_file.pdf\"}","ref":"ExQPDF.html#metadata/2-examples"},{"type":"function","title":"ExQPDF.open/2","doc":"Opens a PDF file, allowing operations that might require a password.","ref":"ExQPDF.html#open/2"},{"type":"function","title":"Parameters - ExQPDF.open/2","doc":"- `path` - Path to the PDF file\n  - `opts` - Options including:\n    - `:password` - Password for protected PDFs","ref":"ExQPDF.html#open/2-parameters"},{"type":"function","title":"Returns - ExQPDF.open/2","doc":"- `{:ok, pdf_handle}` - A handle for further operations\n  - `{:error, reason}` - An error occurred","ref":"ExQPDF.html#open/2-returns"},{"type":"function","title":"Examples - ExQPDF.open/2","doc":"# If the file doesn't exist, an error is returned\n    iex> ExQPDF.open(\"non_existent_file.pdf\")\n    {:error, \"File not found: non_existent_file.pdf\"}\n\n    # With optional password parameter\n    iex> ExQPDF.open(\"non_existent_file.pdf\", password: \"secret\")\n    {:error, \"File not found: non_existent_file.pdf\"}","ref":"ExQPDF.html#open/2-examples"},{"type":"function","title":"ExQPDF.password_required?/1","doc":"Checks if a PDF file requires a password to open.","ref":"ExQPDF.html#password_required?/1"},{"type":"function","title":"Parameters - ExQPDF.password_required?/1","doc":"- `path` - Path to the PDF file","ref":"ExQPDF.html#password_required?/1-parameters"},{"type":"function","title":"Returns - ExQPDF.password_required?/1","doc":"- `{:ok, true}` - The PDF is password-protected\n  - `{:ok, false}` - The PDF is not password-protected\n  - `{:error, reason}` - An error occurred","ref":"ExQPDF.html#password_required?/1-returns"},{"type":"function","title":"Examples - ExQPDF.password_required?/1","doc":"# If the file doesn't exist, an error is returned\n    iex> ExQPDF.password_required?(\"non_existent_file.pdf\")\n    {:error, \"File not found: non_existent_file.pdf\"}","ref":"ExQPDF.html#password_required?/1-examples"},{"type":"module","title":"ExQPDF.Handle","doc":"A handle to a PDF file that has been successfully opened.\n\nThis struct contains information about a PDF file and is used for operations\nthat require continued access to the same file.","ref":"ExQPDF.Handle.html"},{"type":"type","title":"ExQPDF.Handle.t/0","doc":"","ref":"ExQPDF.Handle.html#t:t/0"},{"type":"extras","title":"ExQPDF","doc":"# ExQPDF\n\nAn Elixir wrapper for the [QPDF](https://github.com/qpdf/qpdf) library, a content-preserving PDF document transformer. This library allows you to get information about PDF files and detect if a PDF requires a password.","ref":"readme.html"},{"type":"extras","title":"Prerequisites - ExQPDF","doc":"ExQPDF requires the QPDF command-line tool to be installed on your system.","ref":"readme.html#prerequisites"},{"type":"extras","title":"Installing QPDF - ExQPDF","doc":"ExQPDF requires the QPDF command-line tool to be available in your system PATH.\n\n#### macOS\n\nUsing Homebrew:\n```bash\nbrew install qpdf\n```\n\n#### Ubuntu/Debian\n```bash\nsudo apt-get update\nsudo apt-get install qpdf\n```\n\n#### Fedora/RHEL/CentOS\n```bash\n# Fedora\nsudo dnf install qpdf\n\n# RHEL/CentOS with EPEL\nsudo yum install epel-release\nsudo yum install qpdf\n```\n\n#### Arch Linux\n```bash\nsudo pacman -S qpdf\n```\n\n#### Windows\nOptions for Windows users:\n\n1. **Using Chocolatey**:\n   ```powershell\n   choco install qpdf\n   ```\n\n2. **Using Scoop**:\n   ```powershell\n   scoop install qpdf\n   ```\n\n3. **Manual Installation**:\n   - Download the latest release from [QPDF releases](https://github.com/qpdf/qpdf/releases)\n   - Extract the zip file\n   - Add the bin directory to your PATH\n\n#### Verifying Installation\n\nTo verify that QPDF is installed correctly, run:\n```bash\nqpdf --version\n```\n\nThis should display the installed version of QPDF.","ref":"readme.html#installing-qpdf"},{"type":"extras","title":"Installation - ExQPDF","doc":"Add `ex_qpdf` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_qpdf, \"~> 0.1.1\"}\n  ]\nend\n```\n\nAfter adding the dependency, run:\n\n```\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ExQPDF","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Checking if a PDF requires a password - ExQPDF","doc":"```elixir\n# Check if a PDF requires a password\ncase ExQPDF.password_required?(\"path/to/document.pdf\") do\n  {:ok, true} -> \n    IO.puts(\"This PDF is password-protected\")\n  {:ok, false} -> \n    IO.puts(\"This PDF is not password-protected\")\n  {:error, reason} -> \n    IO.puts(\"Error checking PDF: #{reason}\")\nend\n```","ref":"readme.html#checking-if-a-pdf-requires-a-password"},{"type":"extras","title":"Getting PDF information - ExQPDF","doc":"```elixir\n# Get information about a non-protected PDF\n{:ok, info} = ExQPDF.info(\"path/to/document.pdf\")\nIO.puts(\"Page count: #{info.page_count}\")\n\n# Get information about a password-protected PDF\n{:ok, info} = ExQPDF.info(\"path/to/protected.pdf\", password: \"secret\")\nIO.inspect(info)\n```","ref":"readme.html#getting-pdf-information"},{"type":"extras","title":"Opening a PDF for further operations - ExQPDF","doc":"```elixir\n# Open a PDF for further operations\ncase ExQPDF.open(\"path/to/document.pdf\") do\n  {:ok, handle} -> \n    # Use the handle for further operations (future functionality)\n    IO.inspect(handle)\n  {:error, reason} -> \n    IO.puts(\"Failed to open PDF: #{reason}\")\nend\n\n# Open a password-protected PDF\n{:ok, handle} = ExQPDF.open(\"path/to/protected.pdf\", password: \"secret\")\n```","ref":"readme.html#opening-a-pdf-for-further-operations"},{"type":"extras","title":"Features - ExQPDF","doc":"- Check if a PDF requires a password\n- Get basic information about PDF files (password status, page count)\n- Open PDFs with password support for future operations","ref":"readme.html#features"},{"type":"extras","title":"Roadmap - ExQPDF","doc":"- PDF transformation operations (merge, split)\n- Page extraction\n- Metadata modification\n- Direct access to QPDF's advanced features","ref":"readme.html#roadmap"},{"type":"extras","title":"License - ExQPDF","doc":"Apache License 2.0. See the [LICENSE](LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Attribution - ExQPDF","doc":"ExQPDF is a wrapper around the [QPDF library](https://github.com/qpdf/qpdf).\n\nQPDF is copyright (c) 2005-2021 Jay Berkenbilt, 2022-2025 Jay Berkenbilt and Manfred Holger\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in compliance with the License. You may obtain a copy of the License at\n\nhttps://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License is distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.\n\nVersions of QPDF prior to version 7 were released under the terms of version 2.0 of the Artistic License. For more information, please see the [QPDF repository](https://github.com/qpdf/qpdf).","ref":"readme.html#attribution"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright (c) 2005-2021 Jay Berkenbilt, 2022-2025 Jay Berkenbilt and Manfred Holger\n   Copyright (c) 2025 ExQPDF Contributors\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.\n\nExQPDF is a wrapper around the QPDF library. The original QPDF license information:\n\nqpdf is copyright (c) 2005-2021 Jay Berkenbilt, 2022-2025 Jay Berkenbilt and Manfred Holger\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in compliance with the License. You may obtain a copy of the License at\n\nhttps://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License is distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.\n\nVersions of qpdf prior to version 7 were released under the terms of version 2.0 of the Artistic License. At your option, you may continue to consider qpdf to be licensed under those terms.","ref":"license.html"}],"proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.3"},"content_type":"text/markdown"}